@@ -1,5 +1,10 @@
+#include <Rcpp.h>
+#include <algorithm>  // max_element
+
 #include "primes.h"
 
+// [[Rcpp::interfaces(r, cpp)]]
+
 //' Get the n-th Prime from the Sequence of Primes.
 //'
 //' Get the n-th prime, \eqn{p_n}, in the sequence of primes.
@@ -16,13 +21,13 @@
 //' @author Paul Egeler, MS
 //' @export
 // [[Rcpp::export]]
-Rcpp::IntegerVector nth_prime(const Rcpp::IntegerVector& x) {
+Rcpp::IntegerVector nth_prime(const Rcpp::IntegerVector &x) {
   if (!x.size())
-    return Rcpp::IntegerVector::create();
+    return {};
 
   auto primes = generate_n_primes(*std::max_element(x.begin(), x.end()));
   auto out = Rcpp::IntegerVector(x.size());
-  auto it  = out.begin();
+  auto it = out.begin();
 
   for (auto n : x)
     *(it++) = n > 0 ? primes[n - 1] : NA_INTEGER;
